# GlueMegara

This visualization tool for the MEGARA multi-spectrograph (https://guaix.fis.ucm.es/megara) has been developed with the Glue viewer, since this offers the possibility of defining custom code functions and including them in the file called 'data_viewer.py'. The process has been accomplished at the Universidad Complutense de Madrid in order to create an extensible tool in Python for the analysis of data obtained with MEGARA.


